import { Account, Context, Option, PublicKey, RpcAccount, RpcGetAccountOptions, RpcGetAccountsOptions, Serializer } from '@metaplex-foundation/umi';
import { EscrowConstraint, EscrowConstraintArgs, Key, KeyArgs, RoyaltyInstruction, RoyaltyInstructionArgs } from '../types';
export type EscrowConstraintModel = Account<EscrowConstraintModelAccountData>;
export type EscrowConstraintModelAccountData = {
    key: Key;
    creator: PublicKey;
    name: string;
    constraints: Map<string, EscrowConstraint>;
    updateAuthority: PublicKey;
    count: bigint;
    schemaUri: Option<string>;
    royalties: Map<RoyaltyInstruction, bigint>;
    royaltyBalance: bigint;
    padding: Uint8Array;
};
export type EscrowConstraintModelAccountDataArgs = {
    key: KeyArgs;
    creator: PublicKey;
    name: string;
    constraints: Map<string, EscrowConstraintArgs>;
    updateAuthority: PublicKey;
    count: number | bigint;
    schemaUri: Option<string>;
    royalties: Map<RoyaltyInstructionArgs, number | bigint>;
    royaltyBalance: number | bigint;
    padding: Uint8Array;
};
export declare function getEscrowConstraintModelAccountDataSerializer(context: Pick<Context, 'serializer'>): Serializer<EscrowConstraintModelAccountDataArgs, EscrowConstraintModelAccountData>;
export declare function deserializeEscrowConstraintModel(context: Pick<Context, 'serializer'>, rawAccount: RpcAccount): EscrowConstraintModel;
export declare function fetchEscrowConstraintModel(context: Pick<Context, 'rpc' | 'serializer'>, publicKey: PublicKey, options?: RpcGetAccountOptions): Promise<EscrowConstraintModel>;
export declare function safeFetchEscrowConstraintModel(context: Pick<Context, 'rpc' | 'serializer'>, publicKey: PublicKey, options?: RpcGetAccountOptions): Promise<EscrowConstraintModel | null>;
export declare function fetchAllEscrowConstraintModel(context: Pick<Context, 'rpc' | 'serializer'>, publicKeys: PublicKey[], options?: RpcGetAccountsOptions): Promise<EscrowConstraintModel[]>;
export declare function safeFetchAllEscrowConstraintModel(context: Pick<Context, 'rpc' | 'serializer'>, publicKeys: PublicKey[], options?: RpcGetAccountsOptions): Promise<EscrowConstraintModel[]>;
export declare function getEscrowConstraintModelGpaBuilder(context: Pick<Context, 'rpc' | 'serializer' | 'programs'>): import("@metaplex-foundation/umi").GpaBuilder<EscrowConstraintModel, {
    key: KeyArgs;
    creator: PublicKey;
    name: string;
    constraints: Map<string, EscrowConstraintArgs>;
    updateAuthority: PublicKey;
    count: number | bigint;
    schemaUri: Option<string>;
    royalties: Map<RoyaltyInstructionArgs, number | bigint>;
    royaltyBalance: number | bigint;
    padding: Uint8Array;
}>;
