"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getEscrowConstraintModelGpaBuilder = exports.safeFetchAllEscrowConstraintModel = exports.fetchAllEscrowConstraintModel = exports.safeFetchEscrowConstraintModel = exports.fetchEscrowConstraintModel = exports.deserializeEscrowConstraintModel = exports.getEscrowConstraintModelAccountDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const types_1 = require("../types");
function getEscrowConstraintModelAccountDataSerializer(context) {
    const s = context.serializer;
    return s.struct([
        ['key', (0, types_1.getKeySerializer)(context)],
        ['creator', s.publicKey()],
        ['name', s.string()],
        [
            'constraints',
            s.map(s.string(), (0, types_1.getEscrowConstraintSerializer)(context)),
        ],
        ['updateAuthority', s.publicKey()],
        ['count', s.u64()],
        ['schemaUri', s.option(s.string())],
        ['royalties', s.map((0, types_1.getRoyaltyInstructionSerializer)(context), s.u64())],
        ['royaltyBalance', s.u64()],
        ['padding', s.bytes()],
    ], { description: 'EscrowConstraintModel' });
}
exports.getEscrowConstraintModelAccountDataSerializer = getEscrowConstraintModelAccountDataSerializer;
function deserializeEscrowConstraintModel(context, rawAccount) {
    return (0, umi_1.deserializeAccount)(rawAccount, getEscrowConstraintModelAccountDataSerializer(context));
}
exports.deserializeEscrowConstraintModel = deserializeEscrowConstraintModel;
async function fetchEscrowConstraintModel(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    (0, umi_1.assertAccountExists)(maybeAccount, 'EscrowConstraintModel');
    return deserializeEscrowConstraintModel(context, maybeAccount);
}
exports.fetchEscrowConstraintModel = fetchEscrowConstraintModel;
async function safeFetchEscrowConstraintModel(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    return maybeAccount.exists
        ? deserializeEscrowConstraintModel(context, maybeAccount)
        : null;
}
exports.safeFetchEscrowConstraintModel = safeFetchEscrowConstraintModel;
async function fetchAllEscrowConstraintModel(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts.map((maybeAccount) => {
        (0, umi_1.assertAccountExists)(maybeAccount, 'EscrowConstraintModel');
        return deserializeEscrowConstraintModel(context, maybeAccount);
    });
}
exports.fetchAllEscrowConstraintModel = fetchAllEscrowConstraintModel;
async function safeFetchAllEscrowConstraintModel(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts
        .filter((maybeAccount) => maybeAccount.exists)
        .map((maybeAccount) => deserializeEscrowConstraintModel(context, maybeAccount));
}
exports.safeFetchAllEscrowConstraintModel = safeFetchAllEscrowConstraintModel;
function getEscrowConstraintModelGpaBuilder(context) {
    const s = context.serializer;
    const programId = context.programs.getPublicKey('mplTrifle', 'trifMWutwBxkSuatmpPVnEe7NoE3BJKgjVi8sSyoXWX');
    return (0, umi_1.gpaBuilder)(context, programId)
        .registerFields({
        key: [0, (0, types_1.getKeySerializer)(context)],
        creator: [1, s.publicKey()],
        name: [33, s.string()],
        constraints: [
            null,
            s.map(s.string(), (0, types_1.getEscrowConstraintSerializer)(context)),
        ],
        updateAuthority: [null, s.publicKey()],
        count: [null, s.u64()],
        schemaUri: [null, s.option(s.string())],
        royalties: [
            null,
            s.map((0, types_1.getRoyaltyInstructionSerializer)(context), s.u64()),
        ],
        royaltyBalance: [null, s.u64()],
        padding: [null, s.bytes()],
    })
        .deserializeUsing((account) => deserializeEscrowConstraintModel(context, account));
}
exports.getEscrowConstraintModelGpaBuilder = getEscrowConstraintModelGpaBuilder;
//# sourceMappingURL=escrowConstraintModel.js.map