import { Account, Context, PublicKey, RpcAccount, RpcGetAccountOptions, RpcGetAccountsOptions, Serializer } from '@metaplex-foundation/umi';
import { Key, KeyArgs, TokenAmount, TokenAmountArgs } from '../types';
export type Trifle = Account<TrifleAccountData>;
export type TrifleAccountData = {
    key: Key;
    tokenEscrow: PublicKey;
    tokens: Map<string, Array<TokenAmount>>;
    escrowConstraintModel: PublicKey;
    padding: Uint8Array;
};
export type TrifleAccountDataArgs = {
    key: KeyArgs;
    tokenEscrow: PublicKey;
    tokens: Map<string, Array<TokenAmountArgs>>;
    escrowConstraintModel: PublicKey;
    padding: Uint8Array;
};
export declare function getTrifleAccountDataSerializer(context: Pick<Context, 'serializer'>): Serializer<TrifleAccountDataArgs, TrifleAccountData>;
export declare function deserializeTrifle(context: Pick<Context, 'serializer'>, rawAccount: RpcAccount): Trifle;
export declare function fetchTrifle(context: Pick<Context, 'rpc' | 'serializer'>, publicKey: PublicKey, options?: RpcGetAccountOptions): Promise<Trifle>;
export declare function safeFetchTrifle(context: Pick<Context, 'rpc' | 'serializer'>, publicKey: PublicKey, options?: RpcGetAccountOptions): Promise<Trifle | null>;
export declare function fetchAllTrifle(context: Pick<Context, 'rpc' | 'serializer'>, publicKeys: PublicKey[], options?: RpcGetAccountsOptions): Promise<Trifle[]>;
export declare function safeFetchAllTrifle(context: Pick<Context, 'rpc' | 'serializer'>, publicKeys: PublicKey[], options?: RpcGetAccountsOptions): Promise<Trifle[]>;
export declare function getTrifleGpaBuilder(context: Pick<Context, 'rpc' | 'serializer' | 'programs'>): import("@metaplex-foundation/umi").GpaBuilder<Trifle, {
    key: KeyArgs;
    tokenEscrow: PublicKey;
    tokens: Map<string, Array<TokenAmountArgs>>;
    escrowConstraintModel: PublicKey;
    padding: Uint8Array;
}>;
