"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTrifleGpaBuilder = exports.safeFetchAllTrifle = exports.fetchAllTrifle = exports.safeFetchTrifle = exports.fetchTrifle = exports.deserializeTrifle = exports.getTrifleAccountDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const types_1 = require("../types");
function getTrifleAccountDataSerializer(context) {
    const s = context.serializer;
    return s.struct([
        ['key', (0, types_1.getKeySerializer)(context)],
        ['tokenEscrow', s.publicKey()],
        ['tokens', s.map(s.string(), s.array((0, types_1.getTokenAmountSerializer)(context)))],
        ['escrowConstraintModel', s.publicKey()],
        ['padding', s.bytes()],
    ], { description: 'Trifle' });
}
exports.getTrifleAccountDataSerializer = getTrifleAccountDataSerializer;
function deserializeTrifle(context, rawAccount) {
    return (0, umi_1.deserializeAccount)(rawAccount, getTrifleAccountDataSerializer(context));
}
exports.deserializeTrifle = deserializeTrifle;
async function fetchTrifle(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    (0, umi_1.assertAccountExists)(maybeAccount, 'Trifle');
    return deserializeTrifle(context, maybeAccount);
}
exports.fetchTrifle = fetchTrifle;
async function safeFetchTrifle(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    return maybeAccount.exists ? deserializeTrifle(context, maybeAccount) : null;
}
exports.safeFetchTrifle = safeFetchTrifle;
async function fetchAllTrifle(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts.map((maybeAccount) => {
        (0, umi_1.assertAccountExists)(maybeAccount, 'Trifle');
        return deserializeTrifle(context, maybeAccount);
    });
}
exports.fetchAllTrifle = fetchAllTrifle;
async function safeFetchAllTrifle(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts
        .filter((maybeAccount) => maybeAccount.exists)
        .map((maybeAccount) => deserializeTrifle(context, maybeAccount));
}
exports.safeFetchAllTrifle = safeFetchAllTrifle;
function getTrifleGpaBuilder(context) {
    const s = context.serializer;
    const programId = context.programs.getPublicKey('mplTrifle', 'trifMWutwBxkSuatmpPVnEe7NoE3BJKgjVi8sSyoXWX');
    return (0, umi_1.gpaBuilder)(context, programId)
        .registerFields({
        key: [0, (0, types_1.getKeySerializer)(context)],
        tokenEscrow: [1, s.publicKey()],
        tokens: [
            33,
            s.map(s.string(), s.array((0, types_1.getTokenAmountSerializer)(context))),
        ],
        escrowConstraintModel: [null, s.publicKey()],
        padding: [null, s.bytes()],
    })
        .deserializeUsing((account) => deserializeTrifle(context, account));
}
exports.getTrifleGpaBuilder = getTrifleGpaBuilder;
//# sourceMappingURL=trifle.js.map