"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createEscrowConstraintModelAccount = exports.getCreateEscrowConstraintModelAccountInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
function getCreateEscrowConstraintModelAccountInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        ['name', s.string()],
        ['schemaUri', s.option(s.string())],
    ], { description: 'CreateEscrowConstraintModelAccountInstructionData' }), (value) => ({
        ...value,
        discriminator: 0,
    }));
}
exports.getCreateEscrowConstraintModelAccountInstructionDataSerializer = getCreateEscrowConstraintModelAccountInstructionDataSerializer;
function createEscrowConstraintModelAccount(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTrifle', 'trifMWutwBxkSuatmpPVnEe7NoE3BJKgjVi8sSyoXWX');
    const escrowConstraintModelAccount = input.escrowConstraintModel;
    const payerAccount = input.payer ?? context.payer;
    const updateAuthorityAccount = input.updateAuthority;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    keys.push({
        pubkey: escrowConstraintModelAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(escrowConstraintModelAccount, true),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: updateAuthorityAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(updateAuthorityAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    const data = getCreateEscrowConstraintModelAccountInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.createEscrowConstraintModelAccount = createEscrowConstraintModelAccount;
//# sourceMappingURL=createEscrowConstraintModelAccount.js.map