"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createTrifleAccount = exports.getCreateTrifleAccountInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
function getCreateTrifleAccountInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([['discriminator', s.u8()]], {
        description: 'CreateTrifleAccountInstructionData',
    }), (value) => ({ ...value, discriminator: 1 }));
}
exports.getCreateTrifleAccountInstructionDataSerializer = getCreateTrifleAccountInstructionDataSerializer;
function createTrifleAccount(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTrifle', 'trifMWutwBxkSuatmpPVnEe7NoE3BJKgjVi8sSyoXWX');
    const escrowAccount = input.escrow;
    const metadataAccount = input.metadata;
    const mintAccount = input.mint;
    const tokenAccountAccount = input.tokenAccount;
    const editionAccount = input.edition;
    const trifleAccountAccount = input.trifleAccount;
    const trifleAuthorityAccount = input.trifleAuthority;
    const constraintModelAccount = input.constraintModel;
    const payerAccount = input.payer ?? context.payer;
    const tokenMetadataProgramAccount = input.tokenMetadataProgram ?? {
        ...context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s'),
        isWritable: false,
    };
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const sysvarInstructionsAccount = input.sysvarInstructions ??
        (0, umi_1.publicKey)('Sysvar1nstructions1111111111111111111111111');
    keys.push({
        pubkey: escrowAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(escrowAccount, true),
    });
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(metadataAccount, true),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAccount, false),
    });
    keys.push({
        pubkey: tokenAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenAccountAccount, true),
    });
    keys.push({
        pubkey: editionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(editionAccount, false),
    });
    keys.push({
        pubkey: trifleAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(trifleAccountAccount, true),
    });
    signers.push(trifleAuthorityAccount);
    keys.push({
        pubkey: trifleAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(trifleAuthorityAccount, false),
    });
    keys.push({
        pubkey: constraintModelAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(constraintModelAccount, true),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: tokenMetadataProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenMetadataProgramAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: sysvarInstructionsAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(sysvarInstructionsAccount, false),
    });
    const data = getCreateTrifleAccountInstructionDataSerializer(context).serialize({});
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.createTrifleAccount = createTrifleAccount;
//# sourceMappingURL=createTrifleAccount.js.map