"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setRoyalties = exports.getSetRoyaltiesInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const types_1 = require("../types");
function getSetRoyaltiesInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        ['name', s.string()],
        [
            'royalties',
            s.array(s.tuple([(0, types_1.getRoyaltyInstructionSerializer)(context), s.u64()])),
        ],
    ], { description: 'SetRoyaltiesInstructionData' }), (value) => ({ ...value, discriminator: 8 }));
}
exports.getSetRoyaltiesInstructionDataSerializer = getSetRoyaltiesInstructionDataSerializer;
function setRoyalties(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTrifle', 'trifMWutwBxkSuatmpPVnEe7NoE3BJKgjVi8sSyoXWX');
    const constraintModelAccount = input.constraintModel;
    const payerAccount = input.payer ?? context.payer;
    const updateAuthorityAccount = input.updateAuthority;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const sysvarInstructionsAccount = input.sysvarInstructions ??
        (0, umi_1.publicKey)('Sysvar1nstructions1111111111111111111111111');
    keys.push({
        pubkey: constraintModelAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(constraintModelAccount, true),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    signers.push(updateAuthorityAccount);
    keys.push({
        pubkey: updateAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(updateAuthorityAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: sysvarInstructionsAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(sysvarInstructionsAccount, false),
    });
    const data = getSetRoyaltiesInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.setRoyalties = setRoyalties;
//# sourceMappingURL=setRoyalties.js.map