"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.transferIn = exports.getTransferInInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
function getTransferInInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        ['slot', s.string()],
        ['amount', s.u64()],
    ], { description: 'TransferInInstructionData' }), (value) => ({ ...value, discriminator: 2 }));
}
exports.getTransferInInstructionDataSerializer = getTransferInInstructionDataSerializer;
function transferIn(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTrifle', 'trifMWutwBxkSuatmpPVnEe7NoE3BJKgjVi8sSyoXWX');
    const trifleAccount = input.trifle;
    const trifleAuthorityAccount = input.trifleAuthority;
    const payerAccount = input.payer ?? context.payer;
    const constraintModelAccount = input.constraintModel;
    const escrowAccount = input.escrow;
    const escrowMintAccount = input.escrowMint ?? {
        ...programId,
        isWritable: false,
    };
    const escrowTokenAccount = input.escrowToken ?? {
        ...programId,
        isWritable: false,
    };
    const escrowEditionAccount = input.escrowEdition ?? {
        ...programId,
        isWritable: false,
    };
    const attributeMintAccount = input.attributeMint ?? {
        ...programId,
        isWritable: false,
    };
    const attributeSrcTokenAccount = input.attributeSrcToken ?? {
        ...programId,
        isWritable: false,
    };
    const attributeDstTokenAccount = input.attributeDstToken ?? {
        ...programId,
        isWritable: false,
    };
    const attributeMetadataAccount = input.attributeMetadata ?? {
        ...programId,
        isWritable: false,
    };
    const attributeEditionAccount = input.attributeEdition ?? {
        ...programId,
        isWritable: false,
    };
    const attributeCollectionMetadataAccount = input.attributeCollectionMetadata ?? { ...programId, isWritable: false };
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const splTokenAccount = input.splToken;
    const splAssociatedTokenAccountAccount = input.splAssociatedTokenAccount;
    const tokenMetadataProgramAccount = input.tokenMetadataProgram ?? {
        ...context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s'),
        isWritable: false,
    };
    keys.push({
        pubkey: trifleAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(trifleAccount, true),
    });
    keys.push({
        pubkey: trifleAuthorityAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(trifleAuthorityAccount, true),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: constraintModelAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(constraintModelAccount, true),
    });
    keys.push({
        pubkey: escrowAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(escrowAccount, false),
    });
    keys.push({
        pubkey: escrowMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(escrowMintAccount, false),
    });
    keys.push({
        pubkey: escrowTokenAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(escrowTokenAccount, true),
    });
    keys.push({
        pubkey: escrowEditionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(escrowEditionAccount, true),
    });
    keys.push({
        pubkey: attributeMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(attributeMintAccount, true),
    });
    keys.push({
        pubkey: attributeSrcTokenAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(attributeSrcTokenAccount, true),
    });
    keys.push({
        pubkey: attributeDstTokenAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(attributeDstTokenAccount, true),
    });
    keys.push({
        pubkey: attributeMetadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(attributeMetadataAccount, true),
    });
    keys.push({
        pubkey: attributeEditionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(attributeEditionAccount, true),
    });
    keys.push({
        pubkey: attributeCollectionMetadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(attributeCollectionMetadataAccount, true),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: splTokenAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(splTokenAccount, false),
    });
    keys.push({
        pubkey: splAssociatedTokenAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(splAssociatedTokenAccountAccount, false),
    });
    keys.push({
        pubkey: tokenMetadataProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenMetadataProgramAccount, false),
    });
    const data = getTransferInInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.transferIn = transferIn;
//# sourceMappingURL=transferIn.js.map