"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.transferOut = exports.getTransferOutInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
function getTransferOutInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        ['slot', s.string()],
        ['amount', s.u64()],
    ], { description: 'TransferOutInstructionData' }), (value) => ({ ...value, discriminator: 3 }));
}
exports.getTransferOutInstructionDataSerializer = getTransferOutInstructionDataSerializer;
function transferOut(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTrifle', 'trifMWutwBxkSuatmpPVnEe7NoE3BJKgjVi8sSyoXWX');
    const trifleAccountAccount = input.trifleAccount;
    const constraintModelAccount = input.constraintModel;
    const escrowAccountAccount = input.escrowAccount;
    const escrowTokenAccountAccount = input.escrowTokenAccount;
    const escrowMintAccount = input.escrowMint;
    const escrowMetadataAccount = input.escrowMetadata;
    const escrowEditionAccount = input.escrowEdition ?? {
        ...programId,
        isWritable: false,
    };
    const payerAccount = input.payer ?? context.payer;
    const trifleAuthorityAccount = input.trifleAuthority;
    const attributeMintAccount = input.attributeMint;
    const attributeSrcTokenAccountAccount = input.attributeSrcTokenAccount;
    const attributeDstTokenAccountAccount = input.attributeDstTokenAccount;
    const attributeMetadataAccount = input.attributeMetadata;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const splAssociatedTokenAccountAccount = input.splAssociatedTokenAccount;
    const splTokenAccount = input.splToken;
    const tokenMetadataProgramAccount = input.tokenMetadataProgram ?? {
        ...context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s'),
        isWritable: false,
    };
    const sysvarInstructionsAccount = input.sysvarInstructions ??
        (0, umi_1.publicKey)('Sysvar1nstructions1111111111111111111111111');
    keys.push({
        pubkey: trifleAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(trifleAccountAccount, true),
    });
    keys.push({
        pubkey: constraintModelAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(constraintModelAccount, true),
    });
    keys.push({
        pubkey: escrowAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(escrowAccountAccount, false),
    });
    keys.push({
        pubkey: escrowTokenAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(escrowTokenAccountAccount, true),
    });
    keys.push({
        pubkey: escrowMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(escrowMintAccount, true),
    });
    keys.push({
        pubkey: escrowMetadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(escrowMetadataAccount, true),
    });
    keys.push({
        pubkey: escrowEditionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(escrowEditionAccount, true),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: trifleAuthorityAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(trifleAuthorityAccount, false),
    });
    keys.push({
        pubkey: attributeMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(attributeMintAccount, false),
    });
    keys.push({
        pubkey: attributeSrcTokenAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(attributeSrcTokenAccountAccount, true),
    });
    keys.push({
        pubkey: attributeDstTokenAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(attributeDstTokenAccountAccount, true),
    });
    keys.push({
        pubkey: attributeMetadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(attributeMetadataAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: splAssociatedTokenAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(splAssociatedTokenAccountAccount, false),
    });
    keys.push({
        pubkey: splTokenAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(splTokenAccount, false),
    });
    keys.push({
        pubkey: tokenMetadataProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenMetadataProgramAccount, false),
    });
    keys.push({
        pubkey: sysvarInstructionsAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(sysvarInstructionsAccount, false),
    });
    const data = getTransferOutInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.transferOut = transferOut;
//# sourceMappingURL=transferOut.js.map