"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.withdrawRoyalties = exports.getWithdrawRoyaltiesInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
function getWithdrawRoyaltiesInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        ['name', s.string()],
    ], { description: 'WithdrawRoyaltiesInstructionData' }), (value) => ({ ...value, discriminator: 9 }));
}
exports.getWithdrawRoyaltiesInstructionDataSerializer = getWithdrawRoyaltiesInstructionDataSerializer;
function withdrawRoyalties(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTrifle', 'trifMWutwBxkSuatmpPVnEe7NoE3BJKgjVi8sSyoXWX');
    const constraintModelAccount = input.constraintModel;
    const payerAccount = input.payer ?? context.payer;
    const updateAuthorityAccount = input.updateAuthority;
    const destinationAccount = input.destination;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const sysvarInstructionsAccount = input.sysvarInstructions ??
        (0, umi_1.publicKey)('Sysvar1nstructions1111111111111111111111111');
    keys.push({
        pubkey: constraintModelAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(constraintModelAccount, true),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    signers.push(updateAuthorityAccount);
    keys.push({
        pubkey: updateAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(updateAuthorityAccount, false),
    });
    keys.push({
        pubkey: destinationAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(destinationAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: sysvarInstructionsAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(sysvarInstructionsAccount, false),
    });
    const data = getWithdrawRoyaltiesInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.withdrawRoyalties = withdrawRoyalties;
//# sourceMappingURL=withdrawRoyalties.js.map